@@ -54,6 +54,7 @@ class Gui(abstract.LessonbasedGui):
 
         self.g_entry = gtk.Entry()
         self.g_entry.set_activates_default(True)
+        self.g_entry.connect('changed', self.on_entry_changed)
         self.practise_box.pack_start(self.g_entry, False)
         self.std_buttons_add(
             ('new', self.new_question),
@@ -63,7 +64,6 @@ class Gui(abstract.LessonbasedGui):
             ('give_up', self.give_up),
             ('guess_answer', self.guess_answer)
         )
-        self.g_guess_answer.set_sensitive(False)
         self.g_guess_answer.set_flags(gtk.CAN_DEFAULT)
         self.practise_box.show_all()
         ##############
@@ -79,6 +79,8 @@ class Gui(abstract.LessonbasedGui):
         self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
                                    _("Harmonic progression dictation"))
 
+    def on_entry_changed(self, w):
+        self.g_guess_answer.set_sensitive(bool(self.g_entry.get_text()))
     def guess_answer(self, widget=None):
         if self.m_t.q_status == self.QSTATUS_NO:
             return
